@@ -2054,8 +2054,13 @@ static int relay_recv_index(struct lttcomm_relayd_hdr *recv_hdr,
 		/* no flush. */
 		ret = 0;
 	} else {
+		/*
+		 * ret < 0
+		 *
+		 * relay_index_try_flush is responsible for the self-reference
+		 * put of the index object on error.
+		 */
 		ERR("relay_index_try_flush error %d", ret);
-		relay_index_put(index);
 		ret = -1;
 	}
 
@@ -2255,9 +2260,13 @@ static int handle_index_data(struct relay_stream *stream, uint64_t net_seq_num,
 		/* No flush. */
 		ret = 0;
 	} else {
-		/* Put self-ref for this index due to error. */
-		relay_index_put(index);
-		index = NULL;
+		/*
+		 * ret < 0
+		 *
+		 * relay_index_try_flush is responsible for the self-reference
+		 * put of the index object on error.
+		 */
+		ERR("relay_index_try_flush error %d", ret);
 		ret = -1;
 	}
 end:
