@@ -86,7 +86,6 @@ struct relay_stream *stream_create(struct ctf_trace *trace,
 	stream = zmalloc(sizeof(struct relay_stream));
 	if (stream == NULL) {
 		PERROR("relay stream zmalloc");
-		ret = -1;
 		goto error_no_alloc;
 	}
 
@@ -306,9 +305,9 @@ static void stream_release(struct urcu_ref *ref)
 		stream_fd_put(stream->stream_fd);
 		stream->stream_fd = NULL;
 	}
-	if (stream->index_fd) {
-		stream_fd_put(stream->index_fd);
-		stream->index_fd = NULL;
+	if (stream->index_file) {
+		lttng_index_file_put(stream->index_file);
+		stream->index_file = NULL;
 	}
 	if (stream->trace) {
 		ctf_trace_put(stream->trace);
@@ -345,7 +344,15 @@ void stream_put(struct relay_stream *stream)
 
 void try_stream_close(struct relay_stream *stream)
 {
+	bool session_aborted;
+	struct relay_session *session = stream->trace->session;
+
 	DBG("Trying to close stream %" PRIu64, stream->stream_handle);
+
+	pthread_mutex_lock(&session->lock);
+	session_aborted = session->aborted;
+	pthread_mutex_unlock(&session->lock);
+
 	pthread_mutex_lock(&stream->lock);
 	/*
 	 * Can be called concurently by connection close and reception of last
@@ -387,7 +394,8 @@ void try_stream_close(struct relay_stream *stream)
 	}
 
 	if (stream->last_net_seq_num != -1ULL &&
-			((int64_t) (stream->prev_seq - stream->last_net_seq_num)) < 0) {
+			((int64_t) (stream->prev_seq - stream->last_net_seq_num)) < 0
+			&& !session_aborted) {
 		/*
 		 * Don't close since we still have data pending. This
 		 * handles cases where an explicit close command has
