@@ -53,6 +53,7 @@ struct ustctl_consumer_channel_attr {
 	enum lttng_ust_output output;		/* splice, mmap */
 	uint32_t chan_id;           /* channel ID */
 	unsigned char uuid[LTTNG_UST_UUID_LEN]; /* Trace session unique ID */
+	int64_t blocking_timeout;			/* Retry timeout (usec) */
 } LTTNG_PACKED;
 
 /*
@@ -124,8 +125,6 @@ int ustctl_wait_quiescent(int sock);
 
 int ustctl_sock_flush_buffer(int sock, struct lttng_ust_object_data *object);
 
-int ustctl_calibrate(int sock, struct lttng_ust_calibrate *calibrate);
-
 /* Release object created by members of this API. */
 int ustctl_release_object(int sock, struct lttng_ust_object_data *data);
 /* Release handle returned by create session. */
@@ -217,6 +216,7 @@ int ustctl_put_next_subbuf(struct ustctl_consumer_stream *stream);
 /* snapshot */
 
 int ustctl_snapshot(struct ustctl_consumer_stream *stream);
+int ustctl_snapshot_sample_positions(struct ustctl_consumer_stream *stream);
 int ustctl_snapshot_get_consumed(struct ustctl_consumer_stream *stream,
 		unsigned long *pos);
 int ustctl_snapshot_get_produced(struct ustctl_consumer_stream *stream,
@@ -272,7 +272,7 @@ struct ustctl_integer_type {
 	uint32_t signedness;
 	uint32_t reverse_byte_order;
 	uint32_t base;		/* 2, 8, 10, 16, for pretty print */
-	enum ustctl_string_encodings encoding;
+	int32_t encoding;
 	uint16_t alignment;	/* in bits */
 	char padding[USTCTL_UST_INTEGER_TYPE_PADDING];
 } LTTNG_PACKED;
@@ -293,18 +293,27 @@ struct ustctl_enum_value {
 	char padding[USTCTL_UST_ENUM_VALUE_PADDING];
 } LTTNG_PACKED;
 
+enum ustctl_ust_enum_entry_options {
+	USTCTL_UST_ENUM_ENTRY_OPTION_IS_AUTO = 1U << 0,
+};
+
 #define USTCTL_UST_ENUM_ENTRY_PADDING	32
 struct ustctl_enum_entry {
 	struct ustctl_enum_value start, end; /* start and end are inclusive */
 	char string[LTTNG_UST_SYM_NAME_LEN];
-	char padding[USTCTL_UST_ENUM_ENTRY_PADDING];
+	union {
+		struct {
+			uint32_t options;
+		} LTTNG_PACKED extra;
+		char padding[USTCTL_UST_ENUM_ENTRY_PADDING];
+	} u;
 } LTTNG_PACKED;
 
 #define USTCTL_UST_BASIC_TYPE_PADDING	296
 union _ustctl_basic_type {
 	struct ustctl_integer_type integer;
 	struct {
-		enum ustctl_string_encodings encoding;
+		int32_t encoding;
 	} string;
 	struct ustctl_float_type _float;
 	struct {
