@@ -45,6 +45,8 @@ struct ltt_kernel_channel_list {
 struct ltt_kernel_context {
 	struct lttng_kernel_context ctx;
 	struct cds_list_head list;
+	/* Indicates whether or not the context is in a list. */
+	bool in_list;
 };
 
 /* Kernel event */
@@ -64,6 +66,7 @@ struct ltt_kernel_channel {
 	int enabled;
 	unsigned int stream_count;
 	unsigned int event_count;
+	bool published_to_notification_thread;
 	struct cds_list_head ctx_list;
 	struct lttng_channel *channel;
 	struct ltt_kernel_event_list events_list;
@@ -71,6 +74,7 @@ struct ltt_kernel_channel {
 	struct cds_list_head list;
 	/* Session pointer which has a reference to this object. */
 	struct ltt_kernel_session *session;
+	bool sent_to_consumer;
 };
 
 /* Metadata */
@@ -84,6 +88,7 @@ struct ltt_kernel_stream {
 	int fd;
 	int state;
 	int cpu;
+	bool sent_to_consumer;
 	/* Format is %s_%d respectively channel name and CPU number. */
 	char name[DEFAULT_STREAM_NAME_LEN];
 	uint64_t tracefile_size;
@@ -140,6 +145,8 @@ struct ltt_kernel_stream *trace_kernel_create_stream(const char *name,
 		unsigned int count);
 struct ltt_kernel_context *trace_kernel_create_context(
 		struct lttng_kernel_context *ctx);
+struct ltt_kernel_context *trace_kernel_copy_context(
+		struct ltt_kernel_context *ctx);
 
 /*
  * Destroy functions free() the data structure and remove from linked list if
