@@ -400,6 +400,7 @@ int cmd_enable_channels(int argc, const char **argv)
 	static poptContext pc;
 	char *session_name = NULL;
 	char *opt_arg = NULL;
+	const char *leftover = NULL;
 
 	init_channel_config();
 
@@ -693,6 +694,14 @@ int cmd_enable_channels(int argc, const char **argv)
 		goto mi_closing;
 	}
 
+	leftover = poptGetArg(pc);
+	if (leftover) {
+		ERR("Unknown argument: %s", leftover);
+		ret = CMD_ERROR;
+		success = 0;
+		goto mi_closing;
+	}
+
 	if (!opt_session_name) {
 		session_name = get_session_name();
 		if (session_name == NULL) {
