@@ -1264,6 +1264,7 @@ int cmd_enable_events(int argc, const char **argv)
 	int opt, ret = CMD_SUCCESS, command_ret = CMD_SUCCESS, success = 1;
 	static poptContext pc;
 	char *session_name = NULL;
+	const char *leftover = NULL;
 	int event_type = -1;
 
 	pc = poptGetContext(NULL, argc, argv, long_options, 0);
@@ -1363,6 +1364,13 @@ int cmd_enable_events(int argc, const char **argv)
 		goto end;
 	}
 
+	leftover = poptGetArg(pc);
+	if (leftover) {
+		ERR("Unknown argument: %s", leftover);
+		ret = CMD_ERROR;
+		goto end;
+	}
+
 	if (!opt_session_name) {
 		session_name = get_session_name();
 		if (session_name == NULL) {
