@@ -163,6 +163,7 @@ int cmd_load(int argc, const char **argv)
 	poptContext pc;
 	struct lttng_load_session_attr *session_attr = NULL;
 	char *input_path = NULL;
+	const char *leftover = NULL;
 
 	pc = poptGetContext(NULL, argc, argv, load_opts, 0);
 	poptReadDefaultConfig(pc, 0);
@@ -206,6 +207,13 @@ int cmd_load(int argc, const char **argv)
 		}
 	}
 
+	leftover = poptGetArg(pc);
+	if (leftover) {
+		ERR("Unknown argument: %s", leftover);
+		ret = CMD_ERROR;
+		goto end;
+	}
+
 	/* Mi check */
 	if (lttng_opt_mi) {
 		writer = mi_lttng_writer_create(fileno(stdout), lttng_opt_mi);
