@@ -2558,7 +2558,7 @@ int lttng_list_tracker_pids(struct lttng_handle *handle,
 	int enabled = 1;
 	struct lttcomm_session_msg lsm;
 	size_t nr_pids;
-	int32_t *pids;
+	int32_t *pids = NULL;
 
 	if (handle == NULL) {
 		return -LTTNG_ERR_INVALID;
@@ -2575,6 +2575,9 @@ int lttng_list_tracker_pids(struct lttng_handle *handle,
 		return ret;
 	}
 	nr_pids = ret / sizeof(int32_t);
+	if (nr_pids > 0 && !pids) {
+		return -LTTNG_ERR_UNK;
+	}
 	if (nr_pids == 1 && pids[0] == -1) {
 		free(pids);
 		pids = NULL;
