@@ -1,6 +1,6 @@
 #ifndef _LIBFOO_H
 #define _LIBFOO_H
 
-int foo();
+int foo(void);
 
 #endif  /* _LIBFOO_H */
