@@ -23,12 +23,14 @@
 #include <string.h>
 #include <unistd.h>
 #include <time.h>
+#include <urcu.h>
 
 #include <lttng/lttng.h>
 #include <bin/lttng-sessiond/lttng-ust-abi.h>
 #include <common/defaults.h>
 #include <bin/lttng-sessiond/trace-ust.h>
 #include <bin/lttng-sessiond/ust-app.h>
+#include <bin/lttng-sessiond/notification-thread.h>
 
 #include <tap/tap.h>
 
@@ -48,8 +50,9 @@ int lttng_opt_mi;
 int ust_consumerd32_fd;
 int ust_consumerd64_fd;
 
-/* Global variable required by sessiond objects being linked-in */
+/* Global variables required by sessiond objects being linked-in */
 struct lttng_ht *agent_apps_ht_by_sock;
+struct notification_thread_handle *notification_thread_handle;
 
 static const char alphanum[] =
 	"0123456789"
@@ -84,6 +87,11 @@ static void test_create_one_ust_session(void)
 	usess = trace_ust_create_session(42);
 	ok(usess != NULL, "Create UST session");
 
+	if (!usess) {
+		skip(1, "UST session is null");
+		return;
+	}
+
 	ok(usess->id == 42 &&
 	   usess->active == 0 &&
 	   usess->domain_global.channels != NULL &&
@@ -98,14 +106,22 @@ static void test_create_ust_channel(void)
 {
 	struct ltt_ust_channel *uchan;
 	struct lttng_channel attr;
+	struct lttng_channel_extended extended;
 
 	memset(&attr, 0, sizeof(attr));
+	memset(&extended, 0, sizeof(extended));
+	attr.attr.extended.ptr = &extended;
 
 	ok(lttng_strncpy(attr.name, "channel0", sizeof(attr.name)) == 0,
 		"Validate channel name length");
 	uchan = trace_ust_create_channel(&attr, LTTNG_DOMAIN_UST);
 	ok(uchan != NULL, "Create UST channel");
 
+	if (!usess) {
+		skip(1, "UST session is null");
+		return;
+	}
+
 	ok(uchan->enabled == 0 &&
 	   strncmp(uchan->name, "channel0", 8) == 0 &&
 	   uchan->name[LTTNG_UST_SYM_NAME_LEN - 1] == '\0' &&
@@ -133,6 +149,11 @@ static void test_create_ust_event(void)
 
 	ok(event != NULL, "Create UST event");
 
+	if (!event) {
+		skip(1, "UST event is null");
+		return;
+	}
+
 	ok(event->enabled == 0 &&
 	   event->attr.instrumentation == LTTNG_UST_TRACEPOINT &&
 	   strcmp(event->attr.name, ev.name) == 0 &&
@@ -167,8 +188,8 @@ static void test_create_ust_event_exclusion(void)
 		LTTNG_SYMBOL_NAME_LEN * exclusion_count);
 	ok(exclusion != NULL, "Create UST exclusion");
 	if (!exclusion) {
-		PERROR("zmalloc");
-		abort();
+		skip(4, "zmalloc failed");
+		goto end;
 	}
 
 	exclusion->count = exclusion_count;
@@ -187,8 +208,8 @@ static void test_create_ust_event_exclusion(void)
 		LTTNG_SYMBOL_NAME_LEN * exclusion_count);
 	ok(exclusion != NULL, "Create UST exclusion");
 	if (!exclusion) {
-		PERROR("zmalloc");
-		abort();
+		skip(2, "zmalloc failed");
+		goto end;
 	}
 
 	exclusion->count = exclusion_count;
@@ -198,10 +219,13 @@ static void test_create_ust_event_exclusion(void)
 		get_random_string(), LTTNG_SYMBOL_NAME_LEN);
 
 	event = trace_ust_create_event(&ev, NULL, NULL, exclusion, false);
-	assert(event != NULL);
-
 	ok(event != NULL, "Create UST event with different exclusion names");
 
+	if (!event) {
+		skip(1, "UST event with exclusion is null");
+		goto end;
+	}
+
 	ok(event->enabled == 0 &&
 	   event->attr.instrumentation == LTTNG_UST_TRACEPOINT &&
 	   strcmp(event->attr.name, ev.name) == 0 &&
@@ -213,6 +237,8 @@ static void test_create_ust_event_exclusion(void)
 	   "Validate UST event and exclusion");
 
 	trace_ust_destroy_event(event);
+end:
+	return;
 }
 
 
@@ -237,11 +263,15 @@ int main(int argc, char **argv)
 
 	diag("UST data structures unit test");
 
+	rcu_register_thread();
+
 	test_create_one_ust_session();
 	test_create_ust_channel();
 	test_create_ust_event();
 	test_create_ust_context();
 	test_create_ust_event_exclusion();
 
+	rcu_unregister_thread();
+
 	return exit_status();
 }
